applyAfter property
bool
get
applyAfter
Whether the effect should be applied before or after the base painter. Defaults to true (after).
Implementation
bool get applyAfter => true;
Whether the effect should be applied before or after the base painter. Defaults to true (after).
bool get applyAfter => true;