GradientPainter class
A painter that applies a gradient effect to another painter.
This painter creates a gradient effect with customizable colors, stops, and gradient type properties.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- ShapePainter
- EffectPainter
- GradientPainter
Constructors
-
GradientPainter({required ShapePainter basePainter, required List<
Color> colors, List<double> ? stops, GradientType gradientType = GradientType.linear, bool applyAfter = true}) -
Creates a gradient painter.
const
Properties
- applyAfter → bool
-
Whether the effect should be applied before or after the base painter.
Defaults to true (after).
final
- basePainter → ShapePainter
-
The base painter to apply effects to.
final
-
colors
→ List<
Color> -
The list of colors for the gradient.
final
- gradientType → GradientType
-
The type of gradient to apply.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
-
stops
→ List<
double> ? -
The list of stops for the gradient. If null, colors are distributed evenly.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Paints the shape on the given canvas.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Whether the painter should repaint when the painter instance changes.
inherited
-
shouldRepaint(
covariant CustomPainter oldDelegate) → bool -
Whether the painter should repaint when the size changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override