ShadowPainter class

A painter that applies a shadow effect to another painter.

This painter creates a shadow effect with customizable offset, blur radius, and color properties.

Inheritance

Constructors

ShadowPainter({required ShapePainter basePainter, required Offset offset, required double blurRadius, required Color color, bool applyAfter = true})
Creates a shadow painter.
const

Properties

applyAfter bool
Whether the effect should be applied before or after the base painter. Defaults to true (after).
final
basePainter ShapePainter
The base painter to apply effects to.
final
blurRadius double
The blur radius of the shadow.
final
color Color
The color of the shadow.
final
hashCode int
The hash code for this object.
no setteroverride
offset Offset
The offset of the shadow from the base shape.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Paints the shape on the given canvas.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Whether the painter should repaint when the painter instance changes.
inherited
shouldRepaint(covariant CustomPainter oldDelegate) bool
Whether the painter should repaint when the size changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override