ShadowPainter constructor
const
ShadowPainter({
- required ShapePainter basePainter,
- required Offset offset,
- required double blurRadius,
- required Color color,
- bool applyAfter = true,
Creates a shadow painter.
basePainter is the painter to apply the shadow effect to.
offset is the offset of the shadow from the base shape.
blurRadius is the blur radius of the shadow.
color is the color of the shadow.
applyAfter is whether the shadow should be applied after the base painter.
Implementation
const ShadowPainter({
required this.basePainter,
required this.offset,
required this.blurRadius,
required this.color,
this.applyAfter = true,
});