PolygonPainter class
A painter that draws a polygon on the canvas.
This painter creates a polygon with customizable sides, radius, and stroke properties. It's optimized for performance and supports all Flutter platforms including WASM.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- ShapePainter
- PolygonPainter
Constructors
Properties
- color → Color
-
The fill color of the polygon.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- radius → double
-
The radius of the polygon in logical pixels.
final
- rotation → double
-
The rotation angle in radians.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
- sides → int
-
The number of sides of the polygon.
final
- strokeColor → Color?
-
The color of the polygon's border.
Only used if strokeWidth is not null.
final
- strokeWidth → double?
-
The width of the polygon's border in logical pixels.
If null, no border is drawn.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Paints the shape on the given canvas.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Whether the painter should repaint when the painter instance changes.
inherited
-
shouldRepaint(
covariant CustomPainter oldDelegate) → bool -
Whether the painter should repaint when the size changes.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override