RectanglePainter class

A painter that draws a rectangle on the canvas.

This painter creates a rectangle with customizable dimensions, color, and stroke properties. It's optimized for performance and supports all Flutter platforms including WASM.

Inheritance

Constructors

RectanglePainter({required double width, required double height, required Color color, double? strokeWidth, Color? strokeColor, double? cornerRadius})
Creates a rectangle painter.
const

Properties

color Color
The fill color of the rectangle.
final
cornerRadius double?
The radius of the rectangle's corners in logical pixels. If null, sharp corners are used.
final
hashCode int
The hash code for this object.
no setteroverride
height double
The height of the rectangle in logical pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
strokeColor Color?
The color of the rectangle's border. Only used if strokeWidth is not null.
final
strokeWidth double?
The width of the rectangle's border in logical pixels. If null, no border is drawn.
final
width double
The width of the rectangle in logical pixels.
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Paints the shape on the given canvas.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Whether the painter should repaint when the painter instance changes.
inherited
shouldRepaint(covariant CustomPainter oldDelegate) bool
Whether the painter should repaint when the size changes.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override