ColorUtils class

Utility functions for color operations.

This class provides common functionality for creating and manipulating colors used throughout the package.

Constructors

ColorUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

analogous(Color color, [int count = 3, double spacing = 30.0]) List<Color>
Creates an analogous color scheme.
complementary(Color color) Color
Creates a complementary color.
contrastColor(Color color) Color
Gets the contrast color (black or white) for a given color.
fromHSL(double hue, double saturation, double lightness, [double alpha = 1.0]) Color
Creates a color from HSL values.
fromHSV(double hue, double saturation, double value, [double alpha = 1.0]) Color
Creates a color from HSV values.
isLight(Color color) bool
Checks if a color is light or dark.
monochromatic(Color color, [int count = 5]) List<Color>
Creates a monochromatic color scheme.
tetradic(Color color) List<Color>
Creates a tetradic color scheme.
triadic(Color color) List<Color>
Creates a triadic color scheme.