DotsPatternPainter constructor
const
DotsPatternPainter({})
Creates a dots pattern painter.
spacing is the spacing between dots in logical pixels.
dotSize is the size of each dot in logical pixels.
color is the color of the dots.
repeatPattern is whether the pattern should repeat across the canvas.
patternOffset is the offset from the top-left corner where the pattern starts.
Implementation
const DotsPatternPainter({
required this.spacing,
required this.dotSize,
required this.color,
this.repeatPattern = true,
this.patternOffset = const Offset(0, 0),
}) : elementSize = dotSize;